import type { fdOutgoingPosition } from '../fd';

class Dimensions {
	public width : number;
	public height : number;

	constructor (width : number, height : number) {
		this.width = width;
		this.height = height;
	}

	public getRatio () : number {
		return this.width / this.height;
	}
}

interface Offset {
	x : number;
	y : number;
}

export class Display {

	private screen : Dimensions;
	private source : Dimensions;

	private display : Dimensions;
	private offset : Offset;

	constructor (width : number, height : number) {
		this.screen = new Dimensions(width, height);
		this.offset = { x: 0, y : 0 }
	}

	public setSource (width : number, height : number) {
		this.source = new Dimensions(width, height);
		if (this.source.getRatio() > this.screen.getRatio()) {
			this.display = new Dimensions(this.source.getRatio() * this.screen.height, this.screen.height);
		} else {
			this.display = new Dimensions(this.screen.width, this.source.width / this.source.getRatio());
		}
		this.offset = { x: Math.round(this.display.width),  y : 0 }
	}

	public getDimensions () : fdOutgoingPosition {
		return {
			w : this.display.width,
			h : this.display.height,
			x : this.offset.x,
			y : this.offset.y
		}
	}
}

module.exports = { Display };