import { access, lstat, readdir, realpath } from 'fs/promises';
import type { Stats } from 'fs';
import { Hashes } from '../hash';
import { basename, extname, join } from 'path';

interface SequenceObject {
	path : string,
	hash : string,
	name : string
}

interface VideoObject {
	path : string,
	hash : string,
	name : string
}

interface ImageObject {
	path : string,
	hash : string,
	name : string
}

const videoExtensions : string[] = [
	'.mp4',
	'.mkv',
	'.mov'
];

const imageExtensions : string[] = [
	'.jpg',
	'.jpeg',
	'.png',
	'.tif',
	'.tiff',
	'.bmp'
];

export class Files {
	public static async exists (path : string) : Promise<boolean> {  
		try {
			await access(path);
			return true;
		} catch {
			return false;
		}
	}

	public static async enumerateSequences (path : string) : Promise<SequenceObject[]> {
		const dirs : SequenceObject[] = [];
		let all : string[];
		let stats : Stats;
		let dirPath : string;

		path = await realpath(path);

		try {
			all = await readdir(path)
		} catch (err) {
			throw err;
		}

		for (let elem of all) {
			dirPath = join(path, elem);
			try {
				stats = await lstat(dirPath);
    			if (stats.isDirectory()) {
    				dirs.push({
    					path : dirPath,
    					hash : Hashes.stringHash(dirPath),
    					name : basename(dirPath)
    				});
    			}
			} catch (err) {
				//
			}
		}

		return dirs;
	}

	public static async enumerateVideos (path : string) : Promise<VideoObject[]> {
		const videos : VideoObject[] = [];
		let all : string[];
		let stats : Stats;
		let filePath : string;

		path = await realpath(path);

		try {
			all = await readdir(path)
		} catch (err) {
			throw err;
		}

		for (let elem of all) {
			filePath = join(path, elem);
			try {
				stats = await lstat(filePath);
    			if (stats.isFile() && videoExtensions.indexOf(extname(basename(elem).toLowerCase())) !== -1) {
    				videos.push({
    					path : filePath,
    					hash : Hashes.stringHash(filePath),
    					name : basename(filePath)
    				});
    			}
			} catch (err) {
				//
			}
		}

		return videos;
	}

	public static async enumerateSequence (path : string) : Promise<ImageObject[]> {
		const dirs : ImageObject[] = [];
		let all : string[];
		let stats : Stats;
		let filePath : string;

		path = await realpath(path);

		try {
			all = await readdir(path)
		} catch (err) {
			throw err;
		}

		for (let elem of all) {
			filePath = join(path, elem);
			try {
				stats = await lstat(filePath);
    			if (stats.isFile() && imageExtensions.indexOf(extname(basename(elem).toLowerCase())) !== -1) {
    				dirs.push({
    					path : filePath,
    					hash : Hashes.stringHash(filePath),
    					name : basename(filePath)
    				});
    			}
			} catch (err) {
				//
			}
		}

		return dirs;
	}
}

export type { SequenceObject, VideoObject, ImageObject };
module.exports = { Files };
