import { Files } from '../files';
import { createLog } from '../log'
import type { Logger } from 'winston';
import type { SequenceObject, ImageObject } from '../files';

export class Sequence {
	private log : Logger;
	private current : SequenceObject = null;
	private images : ImageObject[] = [];
	private running : boolean;
	private progress : number;
	private frames : number;

	constructor () {
		this.log = createLog('seq');
	}

	public start () {
		this.running = true;
	}

	public stop () {
		this.running = false;
	}

	public isRunning () {
		return this.running;
	}

	public load (seq : SequenceObject) {
		this.current = seq;
		this.enumerate();
	}

	private async enumerate () {
		if (this.current === null)  {
			this.log.error('Cannot enumerate sequence because it is not set');
			return;
		}

		try {
			this.images = await Files.enumerateSequence(this.current.path);
		} catch (err) {
			this.log.error(`Error enumerating images in sequence: ${this.current.name}`, err);
			return;
		}

		this.log.info(`Sequence ${this.current.name} contains ${this.images.length} image${this.images.length === 1 ? '' : 's'}`);
	}

	public unload () {
		this.current = null;
		this.images = [];
	}

	public getState () : SequenceState {
		return {
			hash : this.current.hash,
			name : this.current.name,
			progress : this.progress
		}
	}
}